@@ -6,7 +6,7 @@ import sys, time, logging
 import numpy as np
 from scipy.ndimage.interpolation import map_coordinates
 from scipy.interpolate import UnivariateSpline, interp1d, InterpolatedUnivariateSpline, RectBivariateSpline
-from aug_sfutils import cocos
+
 
 logger = logging.getLogger('aug_sfutils.mapeq')
 logger.setLevel(logging.INFO)
@@ -311,7 +311,7 @@ def Bmesh(eqm, t_in=None):
 
         jt = index_idx[i]
         Psi = eqm.pfm[:, :, i]
-# Eq 12 in COCOs paper
+# Eq 12 in Coco paper
         Br[jt] = np.apply_along_axis(np.gradient, 1,  Psi)/eqm.Rmesh[:, None]
         Bz[jt] = np.apply_along_axis(np.gradient, 0, -Psi)/eqm.Rmesh[:, None]
         fBt = interp1d(eqm.pfl[i], eqm.jpol[i], kind='linear', fill_value='extrapolate')
@@ -676,8 +676,8 @@ def rhoTheta2rz(eqm, rho, theta_in, t_in=None, coord_in='rho_pol', n_line=201):
     jcoco = eqm.cocos%10 - 1
     if coord_in == 'Psi':
         rho_line[:,:,0] = eqm.psi0[unique_idx][:,None]
-        rho_line *= -eqm.ip_ccw*cocos.sigma['bp'][jcoco]
-        rho      *= -eqm.ip_ccw*cocos.sigma['bp'][jcoco]
+        rho_line *= -eqm.ip_ccw*sigma['bp'][jcoco]
+        rho      *= -eqm.ip_ccw*sigma['bp'][jcoco]
     else:
         #solve some issues very close to the core
         rho_line[:,:,0] = 0
@@ -819,7 +819,7 @@ def get_q_surf(eqm, qvalue=1., t_in=None, coord_out='rho_tor'):
     return np.squeeze(rho_surf)
 
 
-def to_geqdsk(eqm, t_in=0.):
+def to_geqdsk(equ, t_in=0., cocos_out=1):
     """
     Parameters
     ----------
@@ -835,7 +835,8 @@ def to_geqdsk(eqm, t_in=0.):
         omfit_classes.omfit_eqdsk.OMFITgeqdsk objects.
     """
 
-    equ = cocos.coco2coco(eqm, cocos_out=1)
+    if cocos_out is not None:
+        equ.to_coco(cocos_out=cocos_out)
 
     jt = np.argmin(np.abs(equ.time - t_in))
 
@@ -874,10 +875,16 @@ def to_geqdsk(eqm, t_in=0.):
     # Interpolate onto an equidistant Psi-grid
     psi_grid = np.linspace(psi_in[0], psi_in[-1], len(equ.Rmesh))
 
-    geq['QPSI']   = np.interp(psi_grid, psi_in, equ.q[jt])
-    geq['PRES']   = np.interp(psi_grid, psi_in, equ.pres[jt])
-    geq['PPRIME'] = np.interp(psi_grid, psi_in, equ.dpres[jt])
-    geq['FPOL']   = np.interp(psi_grid, psi_in, 2.e-7*equ.jpol[jt] )
-    geq['FFPRIM'] = np.interp(psi_grid, psi_in, -2*np.pi*equ.ffp[jt])
+# np.interp fails if "psi_in" is non-monotonic or not ascending
+    q  = interp1d(psi_in, equ.q[jt]    , kind='linear', fill_value='extrapolate')
+    p  = interp1d(psi_in, equ.pres[jt] , kind='linear', fill_value='extrapolate')
+    dp = interp1d(psi_in, equ.dpres[jt], kind='linear', fill_value='extrapolate')
+    f  = interp1d(psi_in, 2.e-7*equ.jpol[jt], kind='linear', fill_value='extrapolate')
+    df = interp1d(psi_in, -2*np.pi*equ.ffp[jt], kind='linear', fill_value='extrapolate')
+    geq['QPSI']   = q(psi_grid)
+    geq['PRES']   = p(psi_grid)
+    geq['PPRIME'] = dp(psi_grid)
+    geq['FPOL']   = f(psi_grid)
+    geq['FFPRIM'] = df(psi_grid)
 
     return geq
