@@ -70,7 +70,7 @@ class EQU:
             self.ed = self.sf.ed
 
             ## COCO number
-            self.coco = 17
+            self.cocos = 17
 
             ## Time grid of equilibrium shotfile
             self.time = self.sf.getobject('time')
@@ -105,14 +105,14 @@ class EQU:
         logger.info('Reading equ PFM')
         self.read_pfm()
 
-        logger.info('COCO %d' %self.coco)
+        logger.info('COCO %d' %self.cocos)
 
 # Sign of Ip, Bt (positive=ccw from above), valid for COCO=17 (CLISTE)
         self.ip_ccw = np.sign((self.psix - self.psi0).mean())
         self.bt_ccw = np.sign(np.nanmean(self.jpol))
 
-        jcoco = self.coco%10 - 1
-        ebp   = self.coco//10
+        jcoco = self.cocos%10 - 1
+        ebp   = self.cocos//10
         psi_sign = -self.ip_ccw*sigma['bp'][jcoco]*sigma['rphiz'][jcoco]
         psi_2pi  = (2.*np.pi)**ebp
         self.psi_fac = psi_sign*psi_2pi
@@ -389,7 +389,7 @@ class EQU:
             if(sigma['bp'   ][jc] == sigma_bp    and \
                sigma['rphiz'][jc] == sigma_rphiz and \
                rhothephi          == sigma_rhothephi):
-                self.coco = jc + 1
+                self.cocos = jc + 1
                 break
 
 # Find out 2*pi factor for Psi
@@ -402,22 +402,22 @@ class EQU:
         q_ratio = np.abs(np.nanmean(dphi/(self.q*dpsi)))
         logger.debug('Ratio %8.4f' %q_ratio)
         if q_ratio < 4:
-            self.coco += 10
+            self.cocos += 10
 
 
-    def to_coco(self, coco_out=11):
+    def to_coco(self, cocos_out=11):
         """
         Transforms equilibrium object into any wished output COCO
         """
 
 # Assuming SI
 
-        coco_in = self.coco
-        logger.info('COCO conversion from %d to %d' %(coco_in, coco_out))
-        jc_in   = coco_in %10 - 1
-        jc_out  = coco_out%10 - 1
-        ebp_in  = coco_in//10
-        ebp_out = coco_out//10
+        cocos_in = self.cocos
+        logger.info('COCO conversion from %d to %d' %(cocos_in, cocos_out))
+        jc_in   = cocos_in %10 - 1
+        jc_out  = cocos_out%10 - 1
+        ebp_in  = cocos_in//10
+        ebp_out = cocos_out//10
 #    sign_ip_in = np.sign(np.nanmean(self.ipipsi))
 # Equation 9, table I, equation 39, 45
         q_sign   = sigma['rhothephi'][jc_in]*sigma['rhothephi'][jc_out]
@@ -443,7 +443,7 @@ class EQU:
                 self.__dict__[key] = val*phi_sign/psi_fac
             elif key in ('q', 'q0', 'q25', 'q50', 'q75', 'q95'):
                 self.__dict__[key] = val*q_sign
-        self.coco = coco_out
+        self.cocos = cocos_out
 
 
 if __name__ == '__main__':
