@@ -131,6 +131,7 @@ def set_length_address(sfo):
 
 # ParSets
 
+    logger.debug('Diag1 %s', sfo.diag)
     len_psets = 0
     for sfobj in sfo.sfh.values(): # sequence not important
         otyp = sfobj.obj_type
@@ -149,7 +150,6 @@ def set_length_address(sfo):
 
     addr = addr_diag
 
-    len_tot = 0
     for jid in range(len(sfo.sfh)):
 
         objnam = sfo.getobjname(jid)
@@ -163,10 +163,10 @@ def set_length_address(sfo):
             type_len = 0
 
         if otyp == Diagnostic:
-            sfobj.length = sfobj.length # GIT: not really evaluated, determine at the end
+            sfobj.length = sfobj.length # GIT: evaluated at the end of the loop
             sfobj.address = addr
         elif otyp == List:
-            if jid == 1:
+            if objnam == 'SIGNALS':
                 for key, val in sigs.__dict__.items():
                     sfobj.__dict__[key] = val
                 addr = addr_diag
@@ -194,13 +194,17 @@ def set_length_address(sfo):
         else:
             continue
 
-        if otyp not in (Diagnostic, ParamSet):
-            len_tot += sfobj.length
-
         logger.debug('%s (%s)' %(objnam, sfdics.obj_name[otyp]))
         logger.debug('Address in, out: %d %d', addr_in, sfobj.address)
         logger.debug('Length  in, out: %d %d', len_in , sfobj.length )
 
+    len_tot = addr + sfobj.length + addr_diag
+
+    sfobj = sfo.sfh[sfo.diag]
+    len_in = sfobj.length
+    sfobj.length = len_tot
+    logger.debug('%s Length  in, out: %d %d', sfo.diag, len_in , sfobj.length )
+
     return sfo
 
 
@@ -233,6 +237,7 @@ def write_sfh(sfo_in, fout):
         objnam = sfo.getobjname(jid)
         sfobj = sfo.sfh[objnam]
         otyp = sfobj.obj_type
+        
         if otyp in (ParamSet, ):
             pset2byt = bytearray(parset_length(sfobj.pars))
             j0 = 0
@@ -268,7 +273,7 @@ class SFH_WRITE:
         descr    = str_byt.to_byt(sfo.descr)
 
         val_func = { \
-            1 : self.diag, 2: self.list, 3: self.device, 4: self.parmset, \
+            1 : self.sfdiag, 2: self.list, 3: self.device, 4: self.parmset, \
             5 : self.mapping, 6: self.sig, 7: self.sig, 8: self.tbase, \
             9 : self.sf_list, 10: self.algorithm, 11: self.update_set, \
             12: self.loctimer, 13: self.abase, 14: self.qualifier, \
@@ -294,7 +299,7 @@ class SFH_WRITE:
         self.bytstr[64:128] = descr.ljust(64)
 
 
-    def diag(self):
+    def sfdiag(self):
         """
         Metadata of a DIAG object
         """
@@ -359,6 +364,10 @@ class SFH_WRITE:
         """
         Metadata of a Signal or SignalGroup object
         """
+        ind = list(self.sfo.index)[::-1]
+        while len(ind) < 4:
+            ind.append(1)
+        self.sfo.index = ind[::-1]
 
         self.val[  :  2] = pack('>H' , self.sfo.data_format)
         self.val[ 2:  4] = pack('>H' , self.sfo.physunit)
