@@ -417,7 +417,15 @@ class SFREAD:
 
         pscal = self.lincalib(obj)
         if pscal is None:
-            return data
+            if data.phys_unit == 'counts':
+                cal_fac = 1.
+                for rel in data.relations:
+                    if self.sfh[rel].obj_type == TimeBase:
+                        cal_fac = self.sfh[rel].s_rate
+                        break
+                return cal_fac*np.float32(data)
+            else:
+                return data
 
         for j in range(10):
             mult = 'MULTIA0%d' %j
