@@ -39,3 +39,8 @@ def to_small_endian(var):
     if var.dtype.byteorder == '>':
         var = var.newbyteorder().byteswap(inplace=True)
     return var
+
+
+def next8(nlen):
+
+    return 8 * ((nlen + 7) // 8)
